@@ -78,13 +78,13 @@ glade_module_register_widgets (void)
 	glade_register_widget (GNOME_DB_TYPE_FIND_DIALOG,
 			       NULL, glade_standard_build_children,
 			       gnomedb_dialog_find_internal_child);
-	glade_register_widget (GNOME_DB_FORM_TYPE,
+	glade_register_widget (GNOME_DB_TYPE_FORM,
 			       glade_standard_build_widget,
 			       NULL, NULL);
 	glade_register_widget (GNOME_DB_TYPE_GRAY_BAR,
 			       glade_standard_build_widget,
 			       NULL, NULL);
-	glade_register_widget (GNOME_DB_GRID_TYPE,
+	glade_register_widget (GNOME_DB_TYPE_GRID,
 			       glade_standard_build_widget,
 			       NULL, NULL);
 	glade_register_widget (GNOME_DB_TYPE_LOGIN,
