@@ -83,7 +83,7 @@ gnome_db_data_entry_iface_init (gpointer g_class)
 	if (! initialized) {
 		gnome_db_data_entry_signals[CONTENTS_MODIFIED] =
 			g_signal_new ("contents_modified",
-				      GNOME_DB_DATA_ENTRY_TYPE,
+				      GNOME_DB_TYPE_DATA_ENTRY,
 				      G_SIGNAL_RUN_FIRST,
 				      G_STRUCT_OFFSET (GnomeDbDataEntryIface, contents_modified),
 				      NULL, NULL,
@@ -91,7 +91,7 @@ gnome_db_data_entry_iface_init (gpointer g_class)
 				      G_TYPE_NONE, 0);
 		gnome_db_data_entry_signals[STATUS_CHANGED] =
 			g_signal_new ("status_changed",
-				      GNOME_DB_DATA_ENTRY_TYPE,
+				      GNOME_DB_TYPE_DATA_ENTRY,
 				      G_SIGNAL_RUN_FIRST,
 				      G_STRUCT_OFFSET (GnomeDbDataEntryIface, status_changed),
 				      NULL, NULL,
