@@ -151,9 +151,9 @@ gnome_db_join_get_type (void)
 			NULL
 		};
 		
-		type = g_type_register_static (GNOME_DB_BASE_TYPE, "GnomeDbJoin", &info, 0);
-		g_type_add_interface_static (type, GNOME_DB_XML_STORAGE_TYPE, &xml_storage_info);
-		g_type_add_interface_static (type, GNOME_DB_REFERER_TYPE, &referer_info);
+		type = g_type_register_static (GNOME_DB_TYPE_BASE, "GnomeDbJoin", &info, 0);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_XML_STORAGE, &xml_storage_info);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_REFERER, &referer_info);
 	}
 	return type;
 }
@@ -257,7 +257,7 @@ gnome_db_join_new_with_targets (GnomeDbQuery *query, GnomeDbTarget *target_1, Gn
 	g_return_val_if_fail (target_1 != target_2, NULL);
 
 	dict = gnome_db_base_get_dict (GNOME_DB_BASE (query));
-	obj = g_object_new (GNOME_DB_JOIN_TYPE, "dict", dict, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_JOIN, "dict", dict, NULL);
 	gnome_db_join = GNOME_DB_JOIN (obj);
 	gnome_db_base_set_id (GNOME_DB_BASE (gnome_db_join), 0);
 
@@ -322,16 +322,16 @@ gnome_db_join_new_with_xml_ids (GnomeDbQuery *query, const gchar *target_1_xml_i
 	
 
 	dict = gnome_db_base_get_dict (GNOME_DB_BASE (query));
-	obj = g_object_new (GNOME_DB_JOIN_TYPE, "dict", dict, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_JOIN, "dict", dict, NULL);
 	gnome_db_join = GNOME_DB_JOIN (obj);
 	gnome_db_base_set_id (GNOME_DB_BASE (gnome_db_join), 0);
 
 	gnome_db_join->priv->query = query;
 	gnome_db_join->priv->target1 = GNOME_DB_REF_BASE (gnome_db_ref_base_new (dict));
-	gnome_db_ref_base_set_ref_name (gnome_db_join->priv->target1, GNOME_DB_TARGET_TYPE, REFERENCE_BY_XML_ID, target_1_xml_id);
+	gnome_db_ref_base_set_ref_name (gnome_db_join->priv->target1, GNOME_DB_TYPE_TARGET, REFERENCE_BY_XML_ID, target_1_xml_id);
 
 	gnome_db_join->priv->target2 = GNOME_DB_REF_BASE (gnome_db_ref_base_new (dict));
-	gnome_db_ref_base_set_ref_name (gnome_db_join->priv->target2, GNOME_DB_TARGET_TYPE, REFERENCE_BY_XML_ID, target_2_xml_id);
+	gnome_db_ref_base_set_ref_name (gnome_db_join->priv->target2, GNOME_DB_TYPE_TARGET, REFERENCE_BY_XML_ID, target_2_xml_id);
 	
 	gnome_db_base_connect_nullify (query, G_CALLBACK (nullified_object_cb), gnome_db_join);
 
@@ -366,7 +366,7 @@ gnome_db_join_new_copy (GnomeDbJoin *orig, GHashTable *replacements)
 	g_return_val_if_fail (orig && IS_GNOME_DB_JOIN (orig), NULL);
 
 	dict = gnome_db_base_get_dict (GNOME_DB_BASE (orig));
-	obj = g_object_new (GNOME_DB_JOIN_TYPE, "dict", dict, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_JOIN, "dict", dict, NULL);
 	gnome_db_join = GNOME_DB_JOIN (obj);
 	gnome_db_base_set_id (GNOME_DB_BASE (gnome_db_join), 0);
 	if (replacements)
@@ -1221,7 +1221,7 @@ gnome_db_join_load_from_xml (GnomeDbXmlStorage *iface, xmlNodePtr node, GError *
 	prop = xmlGetProp (node, "target1");
 	if (prop) {
 		if (join->priv->target1) {
-			gnome_db_ref_base_set_ref_name (join->priv->target1, GNOME_DB_TARGET_TYPE, 
+			gnome_db_ref_base_set_ref_name (join->priv->target1, GNOME_DB_TYPE_TARGET, 
 						  REFERENCE_BY_XML_ID, prop);
 			t1 = TRUE;
 		}
@@ -1230,7 +1230,7 @@ gnome_db_join_load_from_xml (GnomeDbXmlStorage *iface, xmlNodePtr node, GError *
 	prop = xmlGetProp (node, "target2");
 	if (prop) {
 		if (join->priv->target2) {
-			gnome_db_ref_base_set_ref_name (join->priv->target2, GNOME_DB_TARGET_TYPE, 
+			gnome_db_ref_base_set_ref_name (join->priv->target2, GNOME_DB_TYPE_TARGET, 
 						  REFERENCE_BY_XML_ID, prop);
 			t2 = TRUE;
 		}
