@@ -167,11 +167,11 @@ gnome_db_qf_agg_get_type (void)
 		};
 		
 		
-		type = g_type_register_static (GNOME_DB_QFIELD_TYPE, "GnomeDbQfAgg", &info, 0);
-		g_type_add_interface_static (type, GNOME_DB_XML_STORAGE_TYPE, &xml_storage_info);
-		g_type_add_interface_static (type, GNOME_DB_FIELD_TYPE, &field_info);
-		g_type_add_interface_static (type, GNOME_DB_RENDERER_TYPE, &renderer_info);
-		g_type_add_interface_static (type, GNOME_DB_REFERER_TYPE, &referer_info);
+		type = g_type_register_static (GNOME_DB_TYPE_QFIELD, "GnomeDbQfAgg", &info, 0);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_XML_STORAGE, &xml_storage_info);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_FIELD, &field_info);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_RENDERER, &renderer_info);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_REFERER, &referer_info);
 	}
 	return type;
 }
@@ -278,7 +278,7 @@ gnome_db_qf_agg_new_with_agg (GnomeDbQuery *query, GnomeDbServerAggregate *agg)
 
 	dict = gnome_db_base_get_dict (GNOME_DB_BASE (query));
 
-	obj = g_object_new (GNOME_DB_QF_AGG_TYPE, "dict", dict, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_QF_AGG, "dict", dict, NULL);
 	gnome_db_qf_agg = GNOME_DB_QF_AGG (obj);
 	g_object_get (G_OBJECT (query), "field_serial", &id, NULL);
 	gnome_db_base_set_id (GNOME_DB_BASE (gnome_db_qf_agg), id);
@@ -315,7 +315,7 @@ gnome_db_qf_agg_new_with_xml_id (GnomeDbQuery *query, const gchar *agg_xml_id)
 	g_return_val_if_fail (agg_xml_id && *agg_xml_id, NULL);
 
 	dict = gnome_db_base_get_dict (GNOME_DB_BASE (query));
-	obj = g_object_new (GNOME_DB_QF_AGG_TYPE, "dict", dict, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_QF_AGG, "dict", dict, NULL);
 	gnome_db_qf_agg = GNOME_DB_QF_AGG (obj);
 	g_object_get (G_OBJECT (query), "field_serial", &id, NULL);
 	gnome_db_base_set_id (GNOME_DB_BASE (gnome_db_qf_agg), id);
@@ -325,7 +325,7 @@ gnome_db_qf_agg_new_with_xml_id (GnomeDbQuery *query, const gchar *agg_xml_id)
 				 G_CALLBACK (nullified_object_cb), gnome_db_qf_agg);
 
 	gnome_db_qf_agg->priv->agg_ref = GNOME_DB_REF_BASE (gnome_db_ref_base_new (dict));
-	gnome_db_ref_base_set_ref_name (gnome_db_qf_agg->priv->agg_ref, GNOME_DB_SERVER_AGGREGATE_TYPE, 
+	gnome_db_ref_base_set_ref_name (gnome_db_qf_agg->priv->agg_ref, GNOME_DB_TYPE_SERVER_AGGREGATE, 
 				  REFERENCE_BY_XML_ID, agg_xml_id);
 	
 	return obj;
@@ -786,7 +786,7 @@ gnome_db_qf_agg_load_from_xml (GnomeDbXmlStorage *iface, xmlNodePtr node, GError
 	prop = xmlGetProp (node, "object");
 	if (prop) {
 		aggref = TRUE;
-		gnome_db_ref_base_set_ref_name (agg->priv->agg_ref, GNOME_DB_SERVER_AGGREGATE_TYPE, REFERENCE_BY_XML_ID, prop);
+		gnome_db_ref_base_set_ref_name (agg->priv->agg_ref, GNOME_DB_TYPE_SERVER_AGGREGATE, REFERENCE_BY_XML_ID, prop);
 		g_free (prop);
 	}
 
@@ -821,7 +821,7 @@ gnome_db_qf_agg_load_from_xml (GnomeDbXmlStorage *iface, xmlNodePtr node, GError
 						GnomeDbRefBase *ref;
 						
 						ref = GNOME_DB_REF_BASE (gnome_db_ref_base_new (dict));
-						gnome_db_ref_base_set_ref_name (ref, GNOME_DB_FIELD_TYPE, REFERENCE_BY_XML_ID, prop);
+						gnome_db_ref_base_set_ref_name (ref, GNOME_DB_TYPE_FIELD, REFERENCE_BY_XML_ID, prop);
 						g_free (prop);
 						agg->priv->arg = ref;
 					}
