@@ -30,7 +30,7 @@
 
 G_BEGIN_DECLS
 
-#define GNOME_DB_SERVER_TYPE          (gnome_db_server_get_type())
+#define GNOME_DB_TYPE_SERVER          (gnome_db_server_get_type())
 #define GNOME_DB_SERVER(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gnome_db_server_get_type(), GnomeDbServer)
 #define GNOME_DB_SERVER_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gnome_db_server_get_type (), GnomeDbServerClass)
 #define IS_GNOME_DB_SERVER(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_server_get_type ())
@@ -84,6 +84,12 @@ struct _GnomeDbServerInfo {
 	 */
 	gboolean       implicit_data_types_casts;
 
+	/*
+	 * TRUE if writing "... FROM mytable AS alias..." is ok, and FALSE if we need to write this as
+	 * "... FROM mytable alias..."
+	 */
+	gboolean       alias_needs_as_keyword;
+
 	/*
 	 * Used when looking for a data type from a SQL expression representing a value
 	 */
@@ -188,7 +194,6 @@ void                    gnome_db_server_set_object_func_handler   (GnomeDbServer
 								   GnomeDbDataHandler *(*func)(GnomeDbServer *, GObject *));
 
 /* Convenience function */
-gchar                  *gnome_db_server_stringify_value           (GnomeDbServer *srv, const GdaValue * value);
 gchar                  *gnome_db_server_escape_chars              (GnomeDbServer *srv, const gchar *string);
 GdaDataModel           *gnome_db_server_get_gda_schema            (GnomeDbServer *srv, GdaConnectionSchema schema,
 								   GdaParameterList *params);
