@@ -120,7 +120,7 @@ gnome_db_sql_console_new (GnomeDbDict *dict, const gchar *message)
 
 	g_return_val_if_fail (!dict || IS_GNOME_DB_DICT (dict), NULL);
 
-	obj = g_object_new (GNOME_DB_SQL_CONSOLE_TYPE, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_SQL_CONSOLE, NULL);
 	console = GNOME_DB_SQL_CONSOLE (obj);
 
 	console->priv->dict = ASSERT_DICT (dict);
@@ -434,6 +434,8 @@ fill_context_in_dialog (GnomeDbSqlConsole *console, GnomeDbDataSet *context)
 	return result;
 }
 
+static gchar *compute_events_as_string (GnomeDbServer *serv);
+
 static void
 run_sql_cmde (GnomeDbSqlConsole *console, HistItem *hist_item, const gchar *sql)
 {
@@ -472,19 +474,30 @@ run_sql_cmde (GnomeDbSqlConsole *console, HistItem *hist_item, const gchar *sql)
 				g_free (str);
 				list = g_slist_next (list);
 			}
-			gtk_text_buffer_insert_with_tags_by_name (console->priv->buffer, &iter, string->str, -1, "params_dump", NULL);
+			gtk_text_buffer_insert_with_tags_by_name (console->priv->buffer, &iter, string->str, -1, 
+								  "params_dump", NULL);
 			g_string_free (string, TRUE);
 		}
 
 		/* run query */
 		rsql = gnome_db_renderer_render_as_sql (GNOME_DB_RENDERER (query), dset, 0, &error);
 		if (rsql) {
-			model = gnome_db_server_do_query_as_data_model (gnome_db_dict_get_server (console->priv->dict),
-									rsql, GNOME_DB_SERVER_QUERY_SQL, &error);
+			GnomeDbServer *serv;
+
+			serv = gnome_db_dict_get_server (console->priv->dict);
+			model = gnome_db_server_do_query_as_data_model (serv, rsql, GNOME_DB_SERVER_QUERY_SQL, &error);
 			if (model && (gda_data_model_get_n_rows (model) > 0)) {
+				gchar *str1, *str2;
+
 				cmde_ok = TRUE;
 				str = gda_data_model_dump_as_string (model);
 				g_object_unref (model);
+
+				str1 = compute_events_as_string (serv);
+				str2 = g_strconcat (str, str1);
+				g_free (str1);
+				g_free (str);
+				str = str2;
 			}
 			else {
 				str = NULL;
@@ -495,7 +508,10 @@ run_sql_cmde (GnomeDbSqlConsole *console, HistItem *hist_item, const gchar *sql)
 						str = g_strdup (_("Error: no details"));
 				}
 				if (!str) {
-					str = g_strdup (_("Ok."));
+					str = compute_events_as_string (serv);
+					if (!str)
+						str = g_strdup (_("Ok."));
+					
 					cmde_ok = TRUE;
 				}
 			}
@@ -519,6 +535,52 @@ run_sql_cmde (GnomeDbSqlConsole *console, HistItem *hist_item, const gchar *sql)
 	g_object_unref (query);
 }
 
+static gchar *
+compute_events_as_string (GnomeDbServer *serv)
+{
+	GList *events;
+	gchar *str = NULL;
+	
+	events = gda_connection_get_events (gnome_db_server_get_gda_connection (serv));
+	if (events) {
+		GString *string = NULL;
+		GdaConnectionEvent *event;
+		
+		while (events) {
+			event = GDA_CONNECTION_EVENT (events->data);
+			if (!string)
+				string = g_string_new ("");
+			else
+				g_string_append_c (string, '\n');
+			switch (gda_connection_event_get_event_type (event)) {
+			case GDA_CONNECTION_EVENT_NOTICE:
+				g_string_append (string,
+						 gda_connection_event_get_description (event));
+				break;
+			case GDA_CONNECTION_EVENT_WARNING:
+				g_string_append (string, _("WARNING: "));
+				g_string_append (string,
+						 gda_connection_event_get_description (event));
+				break;
+			case GDA_CONNECTION_EVENT_ERROR:
+				g_string_append (string, _("ERROR: "));
+				g_string_append (string,
+						 gda_connection_event_get_description (event));
+				break;
+			default:
+				g_warning ("Unknown GdaConnectionEvent type");
+				break;
+			}
+			
+			events = g_list_next (events);
+		}
+		str = string->str;
+		g_string_free (string, FALSE);
+	}
+	
+	return str;
+}
+
 static void
 run_internal_cmde (GnomeDbSqlConsole *console, HistItem *hist_item, const gchar *cmde)
 {
