@@ -119,7 +119,7 @@ gnome_db_canvas_db_relations_get_type (void)
 			(GInstanceInitFunc) gnome_db_canvas_db_relations_init
 		};		
 
-		type = g_type_register_static (GNOME_DB_CANVAS_TYPE, "GnomeDbCanvasDbRelations", &info, 0);
+		type = g_type_register_static (GNOME_DB_TYPE_CANVAS, "GnomeDbCanvasDbRelations", &info, 0);
 	}
 	return type;
 }
@@ -474,7 +474,7 @@ gnome_db_canvas_db_relations_new (GnomeDbDict *dict, GnomeDbGraph *graph)
 		g_return_val_if_fail (ASSERT_DICT (dict) == gnome_db_base_get_dict (GNOME_DB_BASE (graph)), NULL);
 	}
 
-        obj = g_object_new (GNOME_DB_CANVAS_DB_RELATIONS_TYPE, "aa", FALSE, NULL);
+        obj = g_object_new (GNOME_DB_TYPE_CANVAS_DB_RELATIONS, "aa", FALSE, NULL);
 	gnome_canvas_set_center_scroll_region (GNOME_CANVAS (obj), TRUE);
 	canvas = GNOME_DB_CANVAS_DB_RELATIONS (obj);
 
@@ -532,7 +532,7 @@ db_constraint_added_cb (GnomeDbDatabase *db, GnomeDbConstraint *cstr, GnomeDbCan
 			FKTables *newkey = g_new0 (FKTables, 1);
 			
 			canvas_item = gnome_canvas_item_new (GNOME_CANVAS_GROUP (root),
-							     GNOME_DB_CANVAS_FKCONSTRAINT_TYPE,
+							     GNOME_DB_TYPE_CANVAS_FKCONSTRAINT,
 							     "fk_constraint", cstr,
 							     NULL);
 			
@@ -606,7 +606,7 @@ graph_item_added (GnomeDbCanvas *canvas, GnomeDbGraphItem *item)
 
 		/* GnomeDbCanvasEntity for the table */
 		canvas_item = gnome_canvas_item_new (GNOME_CANVAS_GROUP (root),
-						     GNOME_DB_CANVAS_ENTITY_TYPE,
+						     GNOME_DB_TYPE_CANVAS_ENTITY,
 						     "popup_menu_func", canvas_entity_popup_func,
 						     "entity", ref_obj,
 						     "x", 50.,
@@ -638,7 +638,7 @@ graph_item_added (GnomeDbCanvas *canvas, GnomeDbGraphItem *item)
 					FKTables *newkey = g_new0 (FKTables, 1);
 					
 					canvas_item = gnome_canvas_item_new (GNOME_CANVAS_GROUP (root),
-									     GNOME_DB_CANVAS_FKCONSTRAINT_TYPE,
+									     GNOME_DB_TYPE_CANVAS_FKCONSTRAINT,
 									     "fk_constraint", fkcons,
 									     NULL);
 					
