@@ -25,7 +25,7 @@
 
 G_BEGIN_DECLS
 
-#define GNOME_DB_CANVAS_QUERY_STRUCT_TYPE          (gnome_db_canvas_query_struct_get_type())
+#define GNOME_DB_TYPE_CANVAS_QUERY_STRUCT          (gnome_db_canvas_query_struct_get_type())
 #define GNOME_DB_CANVAS_QUERY_STRUCT(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gnome_db_canvas_query_struct_get_type(), GnomeDbCanvasQueryStruct)
 #define GNOME_DB_CANVAS_QUERY_STRUCT_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gnome_db_canvas_query_struct_get_type (), GnomeDbCanvasQueryStructClass)
 #define IS_GNOME_DB_CANVAS_QUERY_STRUCT(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_canvas_query_struct_get_type ())
