@@ -27,7 +27,7 @@
 
 G_BEGIN_DECLS
 
-#define GNOME_DB_CANVAS_TYPE          (gnome_db_canvas_get_type())
+#define GNOME_DB_TYPE_CANVAS          (gnome_db_canvas_get_type())
 #define GNOME_DB_CANVAS(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gnome_db_canvas_get_type(), GnomeDbCanvas)
 #define GNOME_DB_CANVAS_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gnome_db_canvas_get_type (), GnomeDbCanvasClass)
 #define IS_GNOME_DB_CANVAS(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_canvas_get_type ())
