@@ -1,6 +1,6 @@
 /* gnome-db-entry-time.c
  *
- * Copyright (C) 2003 Vivien Malerba
+ * Copyright (C) 2003 - 2005 Vivien Malerba
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -112,7 +112,7 @@ gnome_db_entry_time_get_type (void)
 			NULL                                                  /* interface_data */
 		};
 	
-		type = g_type_register_static (GNOME_DB_ENTRY_WRAPPER_TYPE, "GnomeDbEntryTime", &info, 0);
+		type = g_type_register_static (GNOME_DB_TYPE_ENTRY_WRAPPER, "GnomeDbEntryTime", &info, 0);
 		g_type_add_interface_static (type, GTK_TYPE_CELL_EDITABLE, &cell_editable_info);
 	}
 	return type;
@@ -176,7 +176,7 @@ gnome_db_entry_time_new (GnomeDbDataHandler *dh, GdaValueType type)
 	g_return_val_if_fail (type != GDA_VALUE_TYPE_UNKNOWN, NULL);
 	g_return_val_if_fail (gnome_db_data_handler_accepts_gda_type (dh, type), NULL);
 
-	obj = g_object_new (GNOME_DB_ENTRY_TIME_TYPE, "handler", dh, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_ENTRY_TIME, "handler", dh, NULL);
 	mgtim = GNOME_DB_ENTRY_TIME (obj);
 	gnome_db_data_entry_set_value_type (GNOME_DB_DATA_ENTRY (mgtim), type);
 
@@ -447,7 +447,7 @@ real_get_value (GnomeDbEntryWrapper *mgwrap)
 }
 
 static void
-connect_signals(GnomeDbEntryWrapper *mgwrap, GCallback callback)
+connect_signals (GnomeDbEntryWrapper *mgwrap, GCallback callback)
 {
 	GnomeDbEntryTime *mgtim;
 	GdaValueType type;
@@ -493,6 +493,7 @@ expand_in_layout (GnomeDbEntryWrapper *mgwrap)
  * callbacks for the date 
  */
 
+static void internal_set_time (GtkWidget *widget, GnomeDbEntryTime *mgtim);
 static gint date_delete_popup (GtkWidget *widget, GnomeDbEntryTime *mgtim);
 static gint date_key_press_popup (GtkWidget *widget, GdkEventKey *event, GnomeDbEntryTime *mgtim);
 static gint date_button_press_popup (GtkWidget *widget, GdkEventButton *event, GnomeDbEntryTime *mgtim);
@@ -515,6 +516,8 @@ create_entry_date (GnomeDbEntryTime *mgtim)
 	gtk_box_pack_start (GTK_BOX (hb), wid, FALSE, FALSE, 0);
 	gtk_widget_show (wid);
 	mgtim->priv->entry_date = wid;
+	g_signal_connect (G_OBJECT (wid), "changed",
+			  G_CALLBACK (internal_set_time), mgtim);
 	
 	/* window to hold the calendar popup */
 	window = gtk_window_new (GTK_WINDOW_POPUP);
@@ -554,11 +557,38 @@ create_entry_date (GnomeDbEntryTime *mgtim)
 	return hb;
 }
 
-static void hide_popup (GnomeDbEntryTime *mgtim)
+static void
+internal_set_time (GtkWidget *widget, GnomeDbEntryTime *mgtim)
+{
+	/* the aim is that when the mode is TIMESTAMP, when the user sets a date,
+	 * then the time automatically sets to 00:00:00
+	 */
+
+	GdaValueType type;
+
+	type = gnome_db_data_entry_get_value_type (GNOME_DB_DATA_ENTRY (mgtim));
+	if (type == GDA_VALUE_TYPE_TIMESTAMP) {
+		GnomeDbDataHandler *dh;
+		const gchar *str;
+		GdaValue *value;
+
+		dh = gnome_db_data_entry_get_handler (GNOME_DB_DATA_ENTRY (mgtim));
+		str = gtk_entry_get_text (GTK_ENTRY (mgtim->priv->entry_time));
+		value = gnome_db_data_handler_get_value_from_str (dh, str, type);
+		if (!value || gda_value_is_null (value)) 
+			gtk_entry_set_text (GTK_ENTRY (mgtim->priv->entry_time), "00:00:00");
+		if (value)
+			gda_value_free (value);
+	}
+}
+
+static void
+hide_popup (GnomeDbEntryTime *mgtim)
 {
         gtk_widget_hide (mgtim->priv->window);
         gtk_grab_remove (mgtim->priv->window);
 }
+
 static gint
 date_delete_popup (GtkWidget *widget, GnomeDbEntryTime *mgtim)
 {
