@@ -26,7 +26,7 @@
 
 G_BEGIN_DECLS
 
-#define GNOME_DB_ENTRY_TIME_TYPE          (gnome_db_entry_time_get_type())
+#define GNOME_DB_TYPE_ENTRY_TIME          (gnome_db_entry_time_get_type())
 #define GNOME_DB_ENTRY_TIME(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gnome_db_entry_time_get_type(), GnomeDbEntryTime)
 #define GNOME_DB_ENTRY_TIME_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gnome_db_entry_time_get_type (), GnomeDbEntryTimeClass)
 #define IS_GNOME_DB_ENTRY_TIME(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_entry_time_get_type ())
