@@ -119,8 +119,8 @@ gnome_db_entry_wrapper_get_type (void)
 			NULL
 		};
 
-		type = g_type_register_static (GNOME_DB_ENTRY_SHELL_TYPE, "GnomeDbEntryWrapper", &info, 0);
-		g_type_add_interface_static (type, GNOME_DB_DATA_ENTRY_TYPE, &data_entry_info);
+		type = g_type_register_static (GNOME_DB_TYPE_ENTRY_SHELL, "GnomeDbEntryWrapper", &info, 0);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_DATA_ENTRY, &data_entry_info);
 	}
 	return type;
 }
