@@ -27,7 +27,7 @@
 
 G_BEGIN_DECLS
 
-#define GNOME_DB_HANDLER_BOOLEAN_TYPE          (gnome_db_handler_boolean_get_type())
+#define GNOME_DB_TYPE_HANDLER_BOOLEAN          (gnome_db_handler_boolean_get_type())
 #define GNOME_DB_HANDLER_BOOLEAN(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gnome_db_handler_boolean_get_type(), GnomeDbHandlerBoolean)
 #define GNOME_DB_HANDLER_BOOLEAN_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gnome_db_handler_boolean_get_type (), GnomeDbHandlerBooleanClass)
 #define IS_GNOME_DB_HANDLER_BOOLEAN(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_handler_boolean_get_type ())
