@@ -26,7 +26,7 @@
 
 G_BEGIN_DECLS
 
-#define GNOME_DB_ENTRY_TEXT_TYPE          (gnome_db_entry_text_get_type())
+#define GNOME_DB_TYPE_ENTRY_TEXT          (gnome_db_entry_text_get_type())
 #define GNOME_DB_ENTRY_TEXT(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gnome_db_entry_text_get_type(), GnomeDbEntryText)
 #define GNOME_DB_ENTRY_TEXT_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gnome_db_entry_text_get_type (), GnomeDbEntryTextClass)
 #define IS_GNOME_DB_ENTRY_TEXT(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_entry_text_get_type ())
