@@ -105,8 +105,8 @@ gnome_db_handler_cidr_get_type (void)
 			NULL
 		};
 
-		type = g_type_register_static (GNOME_DB_BASE_TYPE, "GnomeDbHandlerCidr", &info, 0);
-		g_type_add_interface_static (type, GNOME_DB_DATA_HANDLER_TYPE, &data_entry_info);
+		type = g_type_register_static (GNOME_DB_TYPE_BASE, "GnomeDbHandlerCidr", &info, 0);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_DATA_HANDLER, &data_entry_info);
 	}
 	return type;
 }
@@ -217,7 +217,7 @@ gnome_db_handler_cidr_new (GnomeDbServer *srv)
 	GnomeDbHandlerCidr *hdl;
 
 	g_return_val_if_fail (srv && IS_GNOME_DB_SERVER (srv), NULL);
-	obj = g_object_new (GNOME_DB_HANDLER_CIDR_TYPE, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_HANDLER_CIDR, NULL);
 	hdl = GNOME_DB_HANDLER_CIDR (obj);
 
 	g_object_add_weak_pointer (G_OBJECT (srv), (gpointer *) &(hdl->priv->srv));
